--- a/tests/test-globalopts.t Tue Jul 16 15:18:12 2013 -0500
+++ b/tests/test-globalopts.t Tue Jul 16 17:10:26 2013 -0500
@@ -324,7 +324,6 @@
rename rename files; equivalent of copy + remove
resolve redo merges or set/view the merge status of files
revert restore files to their checkout state
- rollback roll back the last transaction (dangerous)
root print the root (top) of the current working directory
serve start stand-alone webserver
showconfig show combined config settings from all hgrc files
@@ -407,7 +406,6 @@
rename rename files; equivalent of copy + remove
resolve redo merges or set/view the merge status of files
revert restore files to their checkout state
- rollback roll back the last transaction (dangerous)
root print the root (top) of the current working directory
serve start stand-alone webserver
showconfig show combined config settings from all hgrc files
--- a/tests/test-help.t Tue Jul 16 15:18:12 2013 -0500
+++ b/tests/test-help.t Tue Jul 16 17:10:26 2013 -0500
@@ -89,7 +89,6 @@
rename rename files; equivalent of copy + remove
resolve redo merges or set/view the merge status of files
revert restore files to their checkout state
- rollback roll back the last transaction (dangerous)
root print the root (top) of the current working directory
serve start stand-alone webserver
showconfig show combined config settings from all hgrc files
@@ -166,7 +165,6 @@
rename rename files; equivalent of copy + remove
resolve redo merges or set/view the merge status of files
revert restore files to their checkout state
- rollback roll back the last transaction (dangerous)
root print the root (top) of the current working directory
serve start stand-alone webserver
showconfig show combined config settings from all hgrc files
@@ -652,7 +650,6 @@
rename rename files; equivalent of copy + remove
resolve redo merges or set/view the merge status of files
revert restore files to their checkout state
- rollback roll back the last transaction (dangerous)
root print the root (top) of the current working directory
serve start stand-alone webserver
showconfig show combined config settings from all hgrc files
@@ -1387,13 +1384,6 @@
restore files to their checkout state
</td></tr>
<tr><td>
- <a href="/help/rollback">
- rollback
- </a>
- </td><td>
- roll back the last transaction (dangerous)
- </td></tr>
- <tr><td>
<a href="/help/root">
root
</a>
--- a/mercurial/commands.py Tue Jul 16 15:18:12 2013 -0500
+++ b/mercurial/commands.py Tue Jul 16 17:10:26 2013 -0500
@@ -3541,7 +3541,8 @@
'meaning as the corresponding patch option'), _('NUM')),
('b', 'base', '', _('base path (DEPRECATED)'), _('PATH')),
('e', 'edit', False, _('invoke editor on commit messages')),
- ('f', 'force', None, _('skip check for outstanding uncommitted changes')),
+ ('f', 'force', None,
+ _('skip check for outstanding uncommitted changes (DEPRECATED)')),
('', 'no-commit', None,
_("don't commit, just update the working directory")),
('', 'bypass', None,
@@ -3558,8 +3559,8 @@
Import a list of patches and commit them individually (unless
--no-commit is specified).
- If there are outstanding changes in the working directory, import
- will abort unless given the -f/--force flag.
+ Because import first applies changes to the working directory,
+ import will abort if there are outstanding changes.
You can import a patch straight from a mail message. Even patches
as attachments work (to use the body part, it must have type
@@ -5013,7 +5014,7 @@
@command('rollback', dryrunopts +
[('f', 'force', False, _('ignore safety measures'))])
def rollback(ui, repo, **opts):
"""roll back the last transaction (dangerous)
This command should be used with care. There is only one level of
rollback, and there is no way to undo a rollback. It will also
@@ -5013,7 +5014,7 @@
[('f', 'force', False, _('ignore safety measures'))])
def rollback(ui, repo, **opts):
- """roll back the last transaction (dangerous)
+ """roll back the last transaction (DANGEROUS) (DEPRECATED)
This command should be used with care. There is only one level of
rollback, and there is no way to undo a rollback. It will also